from setuptools import setup, find_packages

setup(
    name='bulk_upload_testrail',
    version='0.1',
    description='A simple Python library for bulk upload to testrail in robot framework.',
    author='Adi Darmawan',
    packages=find_packages(),
)